# speedups Changelog

## [3.0] - 2023-04-26

Change return type in consolideate to `timedelta64[D]`.

## [2.3] - 2019-04-17

### Changed

* Regenerated `C` files to work on Python 3.7
* Updated metadata

### Added

* Changelog
